==> ifrit_3.4.2.orig.tar.gz: ifrit-3.4.2/shells/generic/iggdialogpaletteeditor.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2012 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/


#ifndef IGGDIALOGPALETTEEDITOR_H
#define IGGDIALOGPALETTEEDITOR_H


#include "iggdialog.h"


class iPalette;

class iggWidget;


class iggDialogPaletteEditor : public iggDialog
{

public:

	iggDialogPaletteEditor(iggMainWindow *parent);
	virtual ~iggDialogPaletteEditor();

	void SetCurrentPaletteIndex(int n);
	inline int GetCurrentPaletteIndex() const { return mCurrentPaletteIndex; }
	inline iPalette* GetCurrentPalette() const { return mCurrentPalette; }

	virtual const iString& GetToolTip() const;

	void Apply(bool ask);
	void SetChanged(bool s);

protected:

	virtual void CompleteConstructionBody();
	virtual bool CanBeClosed();

	int mCurrentPaletteIndex;
	iPalette *mCurrentPalette;
	iggWidget *mApplyButton;
};

#endif  //  IGGDIALOGPALETTEEDITOR_H

==> ifrit_4.1.2.orig.tar.gz: ifrit-4.1.2/shells/generic/iggdialogpaletteeditor.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2012 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/


#ifndef IGGDIALOGPALETTEEDITOR_H
#define IGGDIALOGPALETTEEDITOR_H


#include "iggdialog.h"


class iPalette;

class iggWidget;


class iggDialogPaletteEditor : public iggDialog
{

public:

	iggDialogPaletteEditor(iggMainWindow *parent);
	virtual ~iggDialogPaletteEditor();

	void SetActivePaletteIndex(int n);
	inline int GetActivePaletteIndex() const { return mActivePaletteIndex; }
	inline iPalette* GetActivePalette() const { return mActivePalette; }

	virtual const iString& GetToolTip() const;

	void Apply(bool ask = true);
	void SetChanged(bool s);

protected:

	virtual void CompleteConstructionBody();
	virtual bool CanBeClosed();

	int mActivePaletteIndex;
	iPalette *mActivePalette;
	iggWidget *mApplyButton;
};

#endif  //  IGGDIALOGPALETTEEDITOR_H
